/* Imprime los argumentos pasados a main
 * Ejecutar con:
 * $ ./print_main_args 1 2 hola 3.45
 * (ejemplo)
 */
#include <stdio.h>

int main(int argc, char * argv[])
{
  int idx;

  printf("main function argumnets:\n");
  for(idx = 0; idx < argc; idx++)
    printf("- argv[%d]: %s\n", idx, argv[idx]);

  return 0;
}

